@@ -1,8 +1,8 @@
-package Crypt::Random::Source;
-# git description: v0.09-2-ga5f7c6a
-$Crypt::Random::Source::VERSION = '0.10';
+package Crypt::Random::Source; # git description: v0.11-3-gecbdd17
 # ABSTRACT: Get weak or strong random data from pluggable sources
 
+our $VERSION = '0.12';
+
 use strict;
 use 5.008;
 use warnings;
@@ -46,7 +46,7 @@ Crypt::Random::Source - Get weak or strong random data from pluggable sources
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -82,20 +82,18 @@ L<Crypt::Random::Source::Factory>, calling get
 
 L<Crypt::Random>, L<Crypt::Util>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Yuval Kogman.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Florian Ragwitz David Pottage Max Kanat-Alexander
+=for stopwords Karen Etheridge Florian Ragwitz Graham Knop David Pottage Max Kanat-Alexander
 
 =over 4
 
@@ -109,6 +107,10 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
 David Pottage <spudsoup@cpan.org>
 
 =item *
@@ -117,6 +119,13 @@ Max Kanat-Alexander <mkanat@es-compy.(none)>
 
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __END__
